@@ -5,7 +5,7 @@ class Callback():
     def __init__(self):
         pass
 
-    def on_begin_train(self, model:BaseModel):
+    def on_begin_train(self, model:BaseModel, epoch:int):
         pass
 
     def on_end_train(self, model:BaseModel):
@@ -21,4 +21,7 @@ class Callback():
         pass
 
     def on_end_step(self, model:BaseModel, epoch:int, step:int):
+        pass
+
+    def on_end_val(self, model:BaseModel, epoch:int, metric_dict:dict):
         pass
\ No newline at end of file
