@@ -7,13 +7,14 @@ from torchelper.models.base_model import BaseModel
 from torchelper.utils.dist_util import master_only, get_bare_model
 from torchelper.utils import logger
 import os
+import socket
 
 class WechatCallback(Callback):
     def __init__(self, key):
         super().__init__()
         self.url = "https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key="+key
         self.key = key
-     
+        self.hostname = str(socket.gethostname())
     
     def send_msg(self, data):
         try:
@@ -100,7 +101,7 @@ class WechatCallback(Callback):
         data = {
                 "msgtype": "markdown",
                 "markdown": {
-                        "content": msg
+                        "content": "<font color=\"warning\">host</font>:"+self.hostname+"\n"+msg
                     }
                 }
         self.send_msg(data)
