@@ -223,4 +223,13 @@ class ModelBuilder():
         '''用于显示训练期间中间结果音频
         :return: 返回字典类型或None
         '''
-        return None
\ No newline at end of file
+        return None
+
+    @master_only
+    def get_val_dict(self):
+        '''用于获取验证集效果
+        :return: 返回字典类型或None
+        '''
+        return None
+
+ 
\ No newline at end of file
